@@ -142,7 +142,7 @@ class QuerySet(object):
     @return_future
     def delete(self, callback=None, alias=None):
         '''
-        Removes all instance of this document that match the specified filters (if any).
+        Removes all instances of this document that match the specified filters (if any).
 
         .. testsetup:: saving_delete
 
@@ -268,7 +268,7 @@ class QuerySet(object):
 
         Usage::
 
-            User.objects.filter(first_name="Bernardo").filter(last_name="Bernardo").find_all(callback="handle_all")
+            User.objects.filter(first_name="Bernardo").filter(last_name="Bernardo").find_all(callback=handle_all)
             # or
             User.objects.filter(first_name="Bernardo", starting_year__gt=2010).find_all(callback=handle_all)
 
@@ -291,7 +291,7 @@ class QuerySet(object):
 
         Usage::
 
-            User.objects.filter_not(first_name="Bernardo").filter_not(last_name="Bernardo").find_all(callback="handle_all")
+            User.objects.filter_not(first_name="Bernardo").filter_not(last_name="Bernardo").find_all(callback=handle_all)
             # or
             User.objects.filter_not(first_name="Bernardo", starting_year__gt=2010).find_all(callback=handle_all)
 
@@ -312,8 +312,8 @@ class QuerySet(object):
 
         Usage::
 
-            User.objects.limit(10).find_all(callback="handle_all")  # even if there are 100s of users,
-                                                                    # only first 10 will be returned
+            User.objects.limit(10).find_all(callback=handle_all)  # even if there are 100s of users,
+                                                                  # only first 10 will be returned
         '''
 
         self._limit = limit
@@ -327,7 +327,7 @@ class QuerySet(object):
 
             from motorengine import DESCENDING  # or ASCENDING
 
-            User.objects.order_by('first_name', direction=DESCENDING).find_all(callback="handle_all")
+            User.objects.order_by('first_name', direction=DESCENDING).find_all(callback=handle_all)
         '''
 
         if field_name not in self.__klass__._fields:
